==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/FileAllocationDispatcherCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "FileAllocationDispatcherCommand.h"
#include "FileAllocationCommand.h"

bool FileAllocationDispatcherCommand::execute()
{
  if(_e->_requestGroupMan->downloadFinished()) {
    return true;
  }
  
  if(!_e->_fileAllocationMan->isFileAllocationBeingExecuted() &&
     _e->_fileAllocationMan->nextFileAllocationEntryExists()) {
    FileAllocationEntryHandle entry = _e->_fileAllocationMan->popNextFileAllocationEntry();
    logger->info("Dispatching FileAllocationCommand for CUID#%d.",
		 entry->getCUID());
    FileAllocationCommand* command =
      new FileAllocationCommand(entry->getCUID(),
				entry->getRequestGroup(),
				_e,
				entry);
    _e->commands.push_back(command);
    _e->noWait = true;
  }

  _e->commands.push_back(this);

  return false;
}

==> aria2-1.8.1.tar.gz: aria2-1.8.1/src/FileAllocationDispatcherCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "FileAllocationDispatcherCommand.h"
#include "FileAllocationEntry.h"
#include "FileAllocationCommand.h"
#include "message.h"
#include "Logger.h"
#include "DownloadContext.h"

namespace aria2 {

FileAllocationDispatcherCommand::FileAllocationDispatcherCommand
(int32_t cuid,
 const SharedHandle<FileAllocationMan>& fileAllocMan,
 DownloadEngine* e):SequentialDispatcherCommand<FileAllocationEntry>
                    (cuid, fileAllocMan, e) {}

Command* FileAllocationDispatcherCommand::createCommand
(const SharedHandle<FileAllocationEntry>& entry)
{
  int32_t newCUID = _e->newCUID();
  logger->info(MSG_FILE_ALLOCATION_DISPATCH, newCUID);
  FileAllocationCommand* command =
    new FileAllocationCommand(newCUID, entry->getRequestGroup(), _e, entry);
  return command;
}

} // namespace aria2
